<!-- !split -->
<!-- jupyter-book 07_testdoc.md -->
# References

<!-- begin bibliography -->
 1. <a name="Langtangen_Pedersen_2002"></a> **H. P. Langtangen and G. Pedersen**. 
    Propagation of Large Destructive Waves,
    *International Journal of Applied Mechanics and Engineering*,
    7(1),
    pp. 187-204,
    2002.
 2. <a name="Langtangen_et_al_2002"></a> **H. P. Langtangen, K.-A. Mardal and R. Winther**. 
    Numerical Methods for Incompressible Viscous Flow,
    *Advances in Water Resources*,
    25,
    pp. 1125-1146,
    2002.
 3. <a name="Langtangen_1994a"></a> **H. P. Langtangen**. 
    Numerical Solution of First Passage Problems in Random Vibrations,
    *SIAM Journal of Scientific and Statistical Computing*,
    15,
    pp. 997-996,
    1994.
 4. <a name="Mardal_et_al_2003a"></a> **K.-A. Mardal, G. W. Zumbusch and H. P. Langtangen**. 
    Software Tools for Multigrid Methods,
    *Advanced Topics in Computational Partial Differential Equations &ndash; Numerical Methods and Diffpack Programming*,
    edited by **H. P. Langtangen and A. Tveito**,
    Springer,
    2003,
    Edited book,
    <http://some.where.org>.
 5. <a name="Langtangen_1988d"></a> **H. P. Langtangen**. 
    The FEMDEQS Program System,
    *Department of Mathematics, University of Oslo*,
    1989,
    <http://www.math.uio.no/old/days/hpl/femdeqs.pdf>.
 6. <a name="Langtangen_1992c"></a> **H. P. Langtangen**. 
    Stochastic Breakthrough Time Analysis of an Enhanced Oil Recovery Process,
    *SIAM Journal on Scientific Computing*,
    13,
    pp. 1394-1417,
    1992.
 7. <a name="Mortensen_et_al_2011"></a> **M. Mortensen, H. P. Langtangen and G. N. Wells**. 
    A FEniCS-Based Programming Framework for Modeling Turbulent Flow by the Reynolds-Averaged Navier-Stokes Equations,
    *Advances in Water Resources*,
    34(9),
    [doi: 10.1016/j.advwatres.2011.02.013](https://dx.doi.org/10.1016/j.advwatres.2011.02.013),
    2011.
 8. <a name="Glimsdal_et_al_20006"></a> **S. Glimsdal, G. Pedersen, K. Atakan, C. B. Harbitz, H. P. Langtangen and F. L\ovholt**. 
    Propagation of the Dec.\ 26, 2004 Indian Ocean Tsunami: Effects of Dispersion and Source Characteristics,
    *International Journal of Fluid Mechanics Research*,
    33(1),
    pp. 15-43,
    2006.
 9. <a name="Rahman_et_al_2006b"></a> **S. Rahman, J. Gorman, C. H. W. Barnes, D. A. Williams and H. P. Langtangen**. 
    Numerical Investigation of a Piezoelectric Surface Acoustic Wave Interaction With a One-Dimensional Channel,
    *Physical Review B: Condensed Matter and Materials Physics*,
    74,
    2006,
    035308.
10. <a name="Haga_et_al_2011a"></a> **J. B. Haga, H. Osnes and H. P. Langtangen**. 
    On the Causes of Pressure Oscillations in Low-Permeable and Low-Compressible Porous Media,
    *International Journal of Analytical and Numerical Methods in Geomechanics*,
    [doi: 10.1002/nag.1062](https://dx.doi.org/10.1002/nag.1062),
    2011,
    <http://onlinelibrary.wiley.com/doi/10.1002/nag.1062/abstract>.
11. <a name="Langtangen_2003a"></a> **H. P. Langtangen**. 
    *Computational Partial Differential Equations - Numerical Methods and Diffpack Programming*,
    second edition,
    *Texts in Computational Science and Engineering*,
    Springer,
    2003.
12. <a name="Langtangen_2008a"></a> **H. P. Langtangen**. 
    *Python Scripting for Computational Science*,
    third edition,
    *Texts in Computational Science and Engineering*,
    Springer,
    2008.
13. <a name="Langtangen:95"></a> **H. P. Langtangen and G. Pedersen**. 
    Finite Elements for the Boussinesq Wave Equations,
    Waves and Non-linear Processes in Hydrodynamics,
    edited by **J. Grue, B. Gjevik and J. E. Weber**,
    Kluwer Academic Publishers,
    pp. pp. 117-126,
    1995,
    <http://www.amazon.ca/Waves-Nonlinear-Processes-Hydrodynamics-John/dp/0792340310>.
14. <a name="Langtangen_2012"></a> **H. P. Langtangen**. 
    *A Primer on Scientific Programming With Python*,
    third edition,
    *Texts in Computational Science and Engineering*,
    Springer,
    2012.
15. <a name="Jeberg_et_al_2004"></a> **P. V. Jeberg, H. P. Langtangen and C. B. Terp**. 
    Optimization With Diffpack: Practical Example From Welding,
    *Simula Research Laboratory*,
    2004,
    Internal report.
16. <a name="Langtangen_1989e"></a> **H. P. Langtangen**. 
    Computational Methods for Two-Phase Flow in Oil Reservoirs,
    Ph.D. Thesis,
    Mechanics Division, Department of Mathematics, University of Oslo,
    1989,
    Dr.\ Scient.\ thesis..
17. <a name="Langtangen_talk_2007a"></a> **H. P. Langtangen**. 
    Computational Modeling of Huge Tsunamis From Asteroid Impacts,
    2007,
    Invited keynote lecture at the \emphInternational conference on Computational Science 2007 (ICCS'07), Beijing, China.
18. <a name="Langtangen:85"></a> **H. P. Langtangen**. 
    Solution of the Navier-Stokes Equations With the Finite Element Method in Two and Three Dimensions,
    M.Sc. Thesis,
    Mechanics Division, Department of Mathematics, University of Oslo,
    1985,
    Cand.Scient. thesis.
19. <a name="Langtangen:91"></a> **H. P. Langtangen and A. Tveito**. 
    Numerical Methods in Continuum Mechanics,
    *Center for Industrial Research*,
    1991,
    Lecture notes for a course (ME-IN 324). 286 pages..
20. <a name="Langtangen:94b"></a> **H. P. Langtangen**. 
    Diffpack: Software for Partial Differential Equations,
    *Proceedings of the Second Annual Object-Oriented Numerics Conference (OON-SKI'94), Sunriver, Oregon, USA*,
    edited by **A. Vermeulen**,
    1994.

<!-- end bibliography -->

